@@ -1,4 +1,5 @@
 from stdnet import orm
+from stdnet.utils import encoders
 
 from stdnet.contrib.timeseries import models
 
@@ -18,4 +19,9 @@ class TimeSeries(models.TimeSeries):
 class DateTimeSeries(models.DateTimeSeries):
     ticker = orm.SymbolField(unique = True)
     
+    
+class BigTimeSeries(models.DateTimeSeries):
+    ticker = orm.SymbolField(unique = True)
+    data  = models.TimeSeriesField(pickler = encoders.PythonPickle())
+    
 
