@@ -4,6 +4,9 @@ from .mapper import *
 from .fields import *
 from .std import *
 from .signals import *
+from .globals import hashmodel, JSPLITTER
+from .utils import *
+from .search import SearchEngine
 
 
 def test_unique(fieldname, model, value, instance = None, exception = None):
