@@ -61,6 +61,17 @@ to perform cleanup, registration and unregistration.
                 keys.append(key)
         return keys
         
+
+class TestModelBase(TestCase):
+    model = None
+    
+    def register(self):
+        self.orm.register(self.model)
+        self.meta = self.model._meta
+    
+    def unregister(self):
+        self.orm.unregister(self.model)
+        
         
 class TestMultiFieldMixin(object):
     '''Test class which add a couple of tests for multi fields. You need to implement the
@@ -109,13 +120,18 @@ an interable over modules'''
         """Return a suite of all tests cases contained in the given module"""
         itags = itags or []
         tests = []
-        for module in modules:
+        self.all_tags = all_tags = set()
+        self.all_itags = all_itags = set()
+        for module,tag in modules:
+            all_tags.add(tag)
             for name in dir(module):
                 obj = getattr(module, name)
                 if (isclass(obj) and issubclass(obj, self.testClass)):
                     tag = getattr(obj,'tag',None)
-                    if tag and not tag in itags:
-                        continue
+                    if tag:
+                        all_itags.add(tag)
+                        if not tag in itags:
+                            continue
                     tests.append(self.loadTestsFromTestCase(obj))
         return self.suiteClass(tests)
         
