@@ -4,11 +4,19 @@ from stdnet.conf import settings
 
 
 ResponseError = redis.ResponseError
+RedisError = redis.RedisError
+
 
 def makeredis(pool = None):
-    cursor = getdb(settings.DEFAULT_BACKEND)
+    cursor = getdb(format(settings.DEFAULT_BACKEND), decode = 1)
     return cursor.redispy
-    #return redis.Redis(host='localhost', port=6379, db=DBTEST, connection_pool=pool)
+
+
+def get_version(info):
+    if 'redis_version' in info:
+        return info['redis_version']
+    else:
+        return info['Server']['redis_version']
 
 
 class BaseTest(test.TestCase):
